@@ -450,7 +450,7 @@ is filled to the top. If the block position becomes invalid by this
 move it's positioned one up.
 ====================================================================
 */
-int bowl_add_line( Bowl * bowl, int wanted_holes )
+int bowl_add_line( Bowl * bowl, int wanted_holes, int *holes_pos)
 {
     int i, j, holes = 0, hole_x;
     /* if the first line containts a tile the game is over! */
@@ -466,7 +466,12 @@ int bowl_add_line( Bowl * bowl, int wanted_holes )
         bowl_set_tile( bowl, i, bowl->h - 1, rand() % BLOCK_TILE_COUNT );
     /* add holes */
     while ( holes < wanted_holes ) {
-        hole_x = rand() % bowl->w;
+        if ( holes_pos ) {
+	    hole_x = holes_pos[holes];
+	} else {
+            hole_x = rand() % bowl->w;
+	}
+
         if ( bowl->contents[hole_x][bowl->h - 1] != -1 ) {
             bowl_set_tile( bowl, hole_x, bowl->h - 1, -1 );
             holes++;
@@ -515,8 +520,8 @@ void bowl_finish_game( Bowl *bowl )
     bowl_reset_contents( bowl );
     bowl_draw_contents( bowl );
     bowl->font->align = ALIGN_X_CENTER | ALIGN_Y_CENTER;
-    write_text( bowl->font,  offscreen, bowl->sx + bowl->sw / 2, bowl->sy + bowl->sh / 2, "Game Over", OPAQUE );
-    write_text( bowl->font, sdl.screen, bowl->sx + bowl->sw / 2, bowl->sy + bowl->sh / 2, "Game Over", OPAQUE );
+    write_text( bowl->font,  offscreen, bowl->sx + bowl->sw / 2, bowl->sy + bowl->sh / 2, _("Game Over"), OPAQUE );
+    write_text( bowl->font, sdl.screen, bowl->sx + bowl->sw / 2, bowl->sy + bowl->sh / 2, _("Game Over"), OPAQUE );
 #ifdef SOUND
     if ( !bowl->mute ) sound_play( bowl->wav_explosion );
 #endif    
@@ -538,119 +543,145 @@ create shrapnells, give score etc
 */
 void bowl_insert_block( Bowl *bowl )
 {
-    int i, j, l;
-    int line_y[4];
-    int line_count;
-    int line_score;
-    int full;
-    int old_level;
-    int send_count;
-    int shr_type;
-    int py;
-    /* move block y up so it gets to the first free place */
-    py = bowl->block.y * bowl->block_size;
-    while ( !bowl_validate_block_pos( bowl, bowl->block.x, py, bowl->block.rot_id, 0 ) )
-        py -= bowl->block_size;
-    bowl->block.y = py / bowl->block_size;
-    /* insert and check if block is out of screen */
-    for ( i = 0; i < 4; i++ ) {
-        for ( j = 0; j < 4; j++ ) {
-            if ( block_masks[bowl->block.id].mask[bowl->block.rot_id][i][j] ) {
-                if ( bowl->block.y + j < 0 ) bowl->game_over = 1;
-                if ( bowl->block.x + i >= 0 && bowl->block.x + i < bowl->w )
-                    if ( bowl->block.y + j >= 0 && bowl->block.y + j < bowl->h )
-                        bowl_set_tile( bowl, bowl->block.x + i, bowl->block.y + j, bowl->block.id );
-            }
-        }
+  int i, j, k, l;
+  int line_y[4];
+  int line_count;
+  int line_score;
+  int full;
+  int old_level;
+  int send_count;
+  int shr_type;
+  int py;
+  int *hole_pos = 0;
+  /* move block y up so it gets to the first free place */
+  py = bowl->block.y * bowl->block_size;
+  while ( !bowl_validate_block_pos( bowl, bowl->block.x, py, bowl->block.rot_id, 0 ) )
+    py -= bowl->block_size;
+  bowl->block.y = py / bowl->block_size;
+  /* insert and check if block is out of screen */
+  for ( i = 0; i < 4; i++ ) {
+    for ( j = 0; j < 4; j++ ) {
+      if ( block_masks[bowl->block.id].mask[bowl->block.rot_id][i][j] ) {
+	if ( bowl->block.y + j < 0 ) bowl->game_over = 1;
+	if ( bowl->block.x + i >= 0 && bowl->block.x + i < bowl->w )
+	  if ( bowl->block.y + j >= 0 && bowl->block.y + j < bowl->h )
+	    bowl_set_tile( bowl, bowl->block.x + i, bowl->block.y + j, bowl->block.id );
+      }
     }
-    /* draw block to offscreen for shrapnells */
-    bowl_draw_contents( bowl );
+  }
+  /* draw block to offscreen for shrapnells */
+  bowl_draw_contents( bowl );
 #ifdef SOUND
-    if ( !bowl->mute ) sound_play( bowl->wav_stop );
+  if ( !bowl->mute ) sound_play( bowl->wav_stop );
 #endif    
-    /* if game over just explode everything and return */
-    if ( bowl->game_over ) {  
-        bowl_finish_game( bowl );
-        return;
+  /* if game over just explode everything and return */
+  if ( bowl->game_over ) {  
+    bowl_finish_game( bowl );
+    return;
+  }
+  /* check for completed lines */
+  line_count = 0;
+  for ( j = 0; j < bowl->h; j++ ) {
+    full = 1;
+    for ( i = 0; i < bowl->w; i++ ) {
+      if ( bowl->contents[i][j] == -1 ) {
+	full = 0;
+	break;
+      }
     }
-    /* check for completed lines */
-    line_count = 0;
-    for ( j = 0; j < bowl->h; j++ ) {
-        full = 1;
-        for ( i = 0; i < bowl->w; i++ ) {
-            if ( bowl->contents[i][j] == -1 ) {
-                full = 0;
-                break;
-            }
-        }
-        if ( full )
-            line_y[line_count++] = j;
+    if ( full )
+      line_y[line_count++] = j;
+  }
+  for ( j = 0; j < line_count; j++ )
+    for ( i = 0; i < bowl->w; i++ ) {
+      for ( l = line_y[j]; l > 0; l-- )
+	bowl_set_tile( bowl, i, l, bowl->contents[i][l - 1] );
+      bowl_set_tile( bowl, i, 0, -1 );
     }
-    for ( j = 0; j < line_count; j++ )
-        for ( i = 0; i < bowl->w; i++ ) {
-            for ( l = line_y[j]; l > 0; l-- )
-                bowl_set_tile( bowl, i, l, bowl->contents[i][l - 1] );
-            bowl_set_tile( bowl, i, 0, -1 );
-        }
-    /* tetris? tell him! */
+  /* tetris? tell him! */
 #ifdef SOUND
-    if ( line_count == 4 )
-        if ( !bowl->mute ) sound_play( bowl->wav_excellent );
+  if ( line_count == 4 )
+    if ( !bowl->mute ) sound_play( bowl->wav_excellent );
 #endif
-    /* create shrapnells */
-    shr_type = rand() % SHR_TYPE_COUNT;
-    if ( !bowl->blind )
-        for ( j = 0; j < line_count; j++ ) 
-            shrapnells_create( bowl->sx, bowl->sy + line_y[j] * bowl->block_size, bowl->sw, bowl->block_size, shr_type );
+  /* create shrapnells */
+  shr_type = rand() % SHR_TYPE_COUNT;
+  if ( !bowl->blind )
+    for ( j = 0; j < line_count; j++ ) 
+      shrapnells_create( bowl->sx, bowl->sy + line_y[j] * bowl->block_size, bowl->sw, bowl->block_size, shr_type );
 #ifdef SOUND
-    if ( line_count > 0 )
-        if ( !bowl->mute ) sound_play( bowl->wav_explosion );
+  if ( line_count > 0 )
+    if ( !bowl->mute ) sound_play( bowl->wav_explosion );
 #endif    
-    /* add score */
-    line_score = 100 * ( bowl->level + 1 );
-    for ( i = 0; i < line_count; i++ ) {
-        counter_add( &bowl->score, line_score );
-        line_score *= 2;
-    }
-    /* line and level update */
-    old_level = bowl->lines / 10;
-    bowl->lines += line_count;
-    if ( old_level != bowl->lines / 10 ) {
+  /* add score */
+  line_score = 100 * ( bowl->level + 1 );
+  for ( i = 0; i < line_count; i++ ) {
+    counter_add( &bowl->score, line_score );
+    line_score *= 2;
+  }
+  /* line and level update */
+  old_level = bowl->lines / 10;
+  bowl->lines += line_count;
+  if ( old_level != bowl->lines / 10 ) {
 #ifdef SOUND
-        if ( !bowl->mute ) sound_play( bowl->wav_nextlevel );
+    if ( !bowl->mute ) sound_play( bowl->wav_nextlevel );
 #endif    
-        /* new level */
-        bowl->level++;
-        bowl_set_vert_block_vel( bowl );
-        /* in advanced game reset bowl contents */
-        if ( config.gametype == 2 ) {
-            bowl_reset_contents( bowl );
-        }
+    /* new level */
+    bowl->level++;
+    bowl_set_vert_block_vel( bowl );
+    /* in advanced game reset bowl contents */
+    if ( config.gametype == 2 ) {
+      bowl_reset_contents( bowl );
     }
-    /* reset delay of add_line/tile */
-    if ( line_count && ( bowl->add_lines || bowl->add_tiles ) && bowl->dismantle_saves )
-        delay_reset( &bowl->add_delay );
-    /* update offscreen&screen */
-    bowl->draw_contents = 1;
-    /* send completed lines to all other bowls */
-    if ( line_count > 1 ) {
-       send_count = line_count;
-       if ( !config.send_all )
-           send_count--;
-       if ( line_count == 4 && config.send_tetris )
-           send_count = 4;
-        for ( i = 0; i < BOWL_COUNT; i++ )
-            if ( bowls[i] && bowls[i] != bowl && !bowls[i]->game_over) {
-                for ( j = 0; j < send_count; j++ )
-                    if ( !bowl_add_line( bowls[i], config.holes ) ) {
-                        bowl_finish_game( bowls[i] );
-                        return;
-                    }
-                bowls[i]->draw_contents = 1;
-            }
+  }
+  /* reset delay of add_line/tile */
+  if ( line_count && ( bowl->add_lines || bowl->add_tiles ) && bowl->dismantle_saves )
+    delay_reset( &bowl->add_delay );
+  /* update offscreen&screen */
+  bowl->draw_contents = 1;
+  /* send completed lines to all other bowls */
+  if ( line_count > 1 )
+    {
+      send_count = line_count;
+      if ( !config.send_all )
+	send_count--;
+      if ( line_count == 4 && config.send_tetris )
+	send_count = 4;
+
+      for ( i = 0; i < BOWL_COUNT; i++ )
+	if ( bowls[i] && bowls[i] != bowl && !bowls[i]->game_over)
+	  {
+	    if ( !config.rand_holes )
+	      {
+		hole_pos = calloc(config.holes,sizeof(int));
+		for ( j = 0; j < config.holes; )
+		  {
+		    l = rand() % bowls[i]->w;
+		    for (k=0;k<j;k++)
+		      if(hole_pos[k]==l)
+			break;
+		    if (k==j)
+		      {
+			hole_pos[j] = l;
+			j++;
+		      }
+		  }
+	      }
+	    
+	    for ( j = 0; j < send_count; j++ )
+	      if ( !bowl_add_line( bowls[i], config.holes, hole_pos ) )
+		{
+		  bowl_finish_game( bowls[i] );
+		  return;
+		}
+	    bowls[i]->draw_contents = 1;
+	    
+	    if ( hole_pos )
+	      free( hole_pos );
+	    hole_pos = 0;
+	  }
     }
-    /* get next block */
-    bowl_create_next_block( bowl );
+  /* get next block */
+  bowl_create_next_block( bowl );
 }
 /*
 ====================================================================
@@ -687,8 +718,16 @@ int bowl_check_block_insertion( Bowl *bowl )
     }
     if ( !collision ) return 0;
     /* clear the down key so we don't move the next block too far */
-    if ( bowl->controls && keystate[bowl->controls->down] && config.clear_keystate )
+    if ( bowl->controls && config.clear_keystate ) {
         keystate[bowl->controls->down] = 0;
+	if ( config.clear_keystate == 2 ) {
+	    keystate[bowl->controls->left] = 0;
+	    keystate[bowl->controls->right] = 0;
+	    keystate[bowl->controls->rot_left] = 0;
+	    keystate[bowl->controls->rot_right] = 0;
+	    keystate[bowl->controls->drop] = 0;
+	}
+    }
     /* insert, gain score bla bla bla */
     bowl_insert_block( bowl );
     return 1;
@@ -1189,7 +1228,7 @@ void bowl_show( Bowl *bowl )
     sprintf( aux, "%.0f", counter_get_approach( bowl->score ) );
     write_text( bowl->font, sdl.screen, bowl->score_sx + bowl->score_sw - 4, bowl->score_sy + 1, aux, OPAQUE );
     bowl->font->align = ALIGN_X_RIGHT | ALIGN_Y_BOTTOM;
-    sprintf( aux, "%i Lvl: %i", bowl->lines, bowl->level );
+    sprintf( aux, _("%i Lvl: %i"), bowl->lines, bowl->level );
     write_text( bowl->font, sdl.screen, bowl->score_sx + bowl->score_sw - 4, bowl->score_sy + bowl->score_sh, aux, OPAQUE );
 }
 void bowl_update( Bowl *bowl, int ms, int game_over )
@@ -1318,7 +1357,7 @@ void bowl_update( Bowl *bowl, int ms, int game_over )
         {
             if ( bowl->add_lines )
             {
-                bowl_add_line( bowl, bowl->add_line_holes );
+	        bowl_add_line( bowl, bowl->add_line_holes, 0 );
                 bowl->draw_contents = 1;
             }
             if ( bowl->add_tiles )
@@ -1435,13 +1474,13 @@ void bowl_draw_frames( Bowl *bowl )
     /* name&score&level */
     draw_3dframe( bkgnd, dx, dy, dw, dh, 4 );
     bowl->font->align = ALIGN_X_LEFT | ALIGN_Y_TOP;
-    write_text( bowl->font, bkgnd, dx + 4, dy + 4, "Player:", OPAQUE );
+    write_text( bowl->font, bkgnd, dx + 4, dy + 4, _("Player:"), OPAQUE );
     bowl->font->align = ALIGN_X_RIGHT | ALIGN_Y_TOP;
     write_text( bowl->font, bkgnd, dx + dw - 4, dy + 4, bowl->name, OPAQUE );
     bowl->font->align = ALIGN_X_LEFT | ALIGN_Y_CENTER;
-    write_text( bowl->font, bkgnd, dx + 4, dy + dh / 2, "Score:", OPAQUE );
+    write_text( bowl->font, bkgnd, dx + 4, dy + dh / 2, _("Score:"), OPAQUE );
     bowl->font->align = ALIGN_X_LEFT | ALIGN_Y_BOTTOM;
-    write_text( bowl->font, bkgnd, dx + 4, dy + dh - 4, "Lines:", OPAQUE );
+    write_text( bowl->font, bkgnd, dx + 4, dy + dh - 4, _("Lines:"), OPAQUE );
     /* preview */
     if ( bowl->preview_center_sx != -1 )
         draw_3dframe( bkgnd, 
