@@ -720,7 +720,7 @@ void init_sdl( int f )
 
     sdl.screen = 0;
     if (SDL_Init(f) < 0) {
-        fprintf(stderr, "ERR: sdl_init: %s", SDL_GetError());
+        fprintf(stderr, "ERR: sdl_init: %s\n", SDL_GetError());
         exit(1);
     }
     SDL_EnableUNICODE(1);
@@ -861,7 +861,7 @@ int	set_video_mode( Video_Mode mode )
 
     /* set video mode */
     if ( ( sdl.screen = SDL_SetVideoMode( mode.width, mode.height, mode.depth, mode.flags ) ) == 0 ) {
-        fprintf(stderr, "set_video_mode: cannot allocate screen: %s", SDL_GetError());
+        fprintf(stderr, "set_video_mode: cannot allocate screen: %s\n", SDL_GetError());
         return 1;
     }
 
