@@ -42,18 +42,6 @@ extern Sdl sdl;
 extern Config config;
 extern int term_game;
 
-/* a game type index is mapped to the specified highscore */
-char *chart_map[8] = {
-    "Demo",
-    "Classic",
-    "Figures",
-    "Two-Player",
-    "Two-Player",
-    "Three-Player",
-    "Three-Player",
-    "Three-Player"
-};
-
 /*
 ====================================================================
 Locals
@@ -357,6 +345,20 @@ void tetris_run()
     int gain_multiplayer_bonus = 0;
     int escape = 0;
     
+    /* HACK: moved due to i18n
+       a game type index is mapped to the specified highscore */
+    char *chart_map[8] = {
+        _("Demo"),
+        _("Classic"),
+        _("Figures"),
+        _("Two-Player"),
+        _("Two-Player"),
+        _("Three-Player"),
+        _("Three-Player"),
+        _("Three-Player")
+    };
+    
+    
     /* count number of bowls */
     bowl_count = 0;
     for ( i = 0; i < BOWL_COUNT; i++ )
@@ -394,7 +396,7 @@ void tetris_run()
                                 break;
                             }
                             escape = 1;
-                            if ( confirm( large_font, "End Game? y/n", CONFIRM_YES_NO ) ) 
+                            if ( confirm( large_font, _("End Game? y/n"), CONFIRM_YES_NO ) ) 
                                 for ( i = 0; i < BOWL_COUNT; i++ )
                                     if ( bowls[i] && !bowls[i]->game_over )
                                         bowl_finish_game( bowls[i] );
